function error = costMultiRectification(a,width,height,correspondences,referenceImage)
% computes a rectification cost for non linear minimization.
%
% ERROR = COSTMULTIRECITFICATION(A,WIDTH,HEIGHT,CORRESPONDENCES,REFERENCEIMAGE)
% tests if the parameters stored in the vector A provides a good
% rectification and return the error cost ERROR. WIDTH and HEIGHT are the
% images resolution, CORRESPONDENCES is a cell array containing pixel list
% describing the point correspondences. REFERENCEIMAGE is the id of the
% image that will not have any rotation around the 'horizontal axis' 
% (default is 1).
%
% Copyright (C) by University Paris-Est - Vincent NOZICK   
% Mail : nozick@univ-mlv.fr
%   
% This source code is free software; you can redistribute it and/or modify
% it under the terms of the GNU Lesser General Public License as published by
% the Free Software Foundation; either version 3 of the License, or
% (at your option) any later version.
%
% This source code is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
% GNU Lesser General Public License for more details.
%
% You should have received a copy of the GNU Lesser General Public License
% along with this program. If not, see <http://www.gnu.org/licenses/>.
% 
% Author : Vincent Nozick (nozick@univ-mlv.fr)

% general data
nbCamera = length(correspondences);
nbCorrespondences = length(correspondences{1});
if nargin == 4
    referenceImage = 1;
end

% get the homograhies
H = getHomographies(a,width,height,referenceImage);

% error computation
error = zeros(nbCorrespondences,1);

% each correspondence contribution
for i = 1:nbCorrespondences
    % compute the average value of y
    average = 0;
    for j = 1:nbCamera
        pt = H{j} * correspondences{j}(i,:)';
        pt = pt / pt(3);
        average = average + pt(2);
    end
    average = average / nbCamera;
    
    % compute the error = sum of the y-difference with the y-average
    for j = 1:nbCamera
        pt = H{j} * correspondences{j}(i,:)';
        pt = pt / pt(3);
        error(i) = error(i) + (average - pt(2))^2;
    end
end









