function imagesOut = drawCorrepsondences(imagesIn,correspondences)
% Draw a set of points on a set of images.
%
% IMAGESOUT = DRAWCORRESPONDENCES(IMAGESIN,CORRESPONDENCES) makes a copy of
% the images contained in the cell array IMAGESIN. CORRESPONDENCES is aslo
% a cell array with the same number of elements than the number of images.
% Each element of the CORRESPONDENCES is a list of 2d pixels (same number 
% of pixels in every list). For each correspondence, the program chooses a
% random color and draws the pixels on the corresponding image.
%
% Copyright (C) by University Paris-Est - Vincent NOZICK   
% Mail : nozick@univ-mlv.fr
%   
% This source code is free software; you can redistribute it and/or modify
% it under the terms of the GNU Lesser General Public License as published by
% the Free Software Foundation; either version 3 of the License, or
% (at your option) any later version.
%
% This source code is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
% GNU Lesser General Public License for more details.
%
% You should have received a copy of the GNU Lesser General Public License
% along with this program. If not, see <http://www.gnu.org/licenses/>.
% 
% Author : Vincent Nozick (nozick@univ-mlv.fr)


% copy the input images
imagesOut = imagesIn;

% draw the point correspondences
for correspondenceId=1:length(correspondences{1})
    % choose a random color
    color = 255*rand(3,1);
    for imageId=1:length(imagesOut)
        i = int16(correspondences{imageId}(correspondenceId,1));
        j = int16(correspondences{imageId}(correspondenceId,2));
        
        imagesOut{imageId} = imageDrawCircle(imagesOut{imageId},[i,j],3,color);    
    end
end