function R = eulerAngles(a)
% computes a rotation matrix from 3 Euler angles in radian, the rotation 
% are applied in the order x-y-z (first x, last z).
%
% R = EULERANGLES(A) computes a 3x3 rotation matrix R from 3 angles
% (x-y-z) specified in A, in radian. 
%
% Copyright (C) by University Paris-Est - Vincent NOZICK   
% Mail : nozick@univ-mlv.fr
%   
% This source code is free software; you can redistribute it and/or modify
% it under the terms of the GNU Lesser General Public License as published by
% the Free Software Foundation; either version 3 of the License, or
% (at your option) any later version.
%
% This source code is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
% GNU Lesser General Public License for more details.
%
% You should have received a copy of the GNU Lesser General Public License
% along with this program. If not, see <http://www.gnu.org/licenses/>.
% 
% Author : Vincent Nozick (nozick@univ-mlv.fr)


% get back the angles
angleX = a(1); % rotation angle around x
angleY = a(2); % rotation angle around y
angleZ = a(3); % rotation angle around z

% Rx
Rx = [ 1,  0,           0; 
       0,  cos(angleX), sin(angleX);
       0, -sin(angleX), cos(angleX)]; 

% Ry
Ry = [ cos(angleY), 0, sin(angleY);
       0          , 1, 0; 
      -sin(angleY), 0,  cos(angleY)];  

% Rz
Rz =  [ cos(angleZ), -sin(angleZ), 0;
        sin(angleZ),  cos(angleZ), 0;
        0          ,  0          , 1 ];

% R
R =  Rz * Ry * Rx; 



