function H = getHomographies(a,width,height,referenceImage)
% Extract the homographies from the vector a and some constants
%
% H = GETHOMOGRAPHIES(A,WIDTH,HEIGHT,REFERENCEIMAGE) extract the values 
% from vector A and builds the homographies according to these values.
% WIDTH and HEIGHT are 2 arrays correpsonding to the images resolution. 
% REFERENCEIMAGE is the id of the image that will not have rotation around
% the 'horizontal axis'.
%
% Copyright (C) by University Paris-Est - Vincent NOZICK   
% Mail : nozick@univ-mlv.fr
%   
% This source code is free software; you can redistribute it and/or modify
% it under the terms of the GNU Lesser General Public License as published by
% the Free Software Foundation; either version 3 of the License, or
% (at your option) any later version.
%
% This source code is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
% GNU Lesser General Public License for more details.
%
% You should have received a copy of the GNU Lesser General Public License
% along with this program. If not, see <http://www.gnu.org/licenses/>.
% 
% Author : Vincent Nozick (nozick@univ-mlv.fr)

% general data
nbCamera = length(width);

% recover the parameters
Rx = zeros(1,nbCamera);
Ry = zeros(1,nbCamera);
Rz = zeros(1,nbCamera);
alpha = zeros(1,nbCamera);
for i=1:nbCamera
    Rx(i)    = a(4*(i-1) +1);
    Ry(i)    = a(4*(i-1) +2);
    Rz(i)    = a(4*(i-1) +3);
    alpha(i) = a(4*(i-1) +4);   
end

% build the camera internal parameters
Koriginal = cell(1,nbCamera);
Knew = cell(1,nbCamera);
for i=1:nbCamera
    % Koriginal
    originalFocal = sqrt(width{i}*width{i} + height{i}*height{i});
    Koriginal{i} = diag([originalFocal,originalFocal,1]);

    % Knew
    if i == referenceImage
        Knew{i} = Koriginal{i};
    else
        focal = originalFocal * 3^alpha(i);
        Knew{i} = diag([focal,focal,1]);
    end    
end

% build the centering homography
Hcenter = cell(1,nbCamera);
for i=1:nbCamera
    Hcenter{i} = eye(3);
    Hcenter{i}(1,3) = -width{i}/2;
    Hcenter{i}(2,3) = -height{i}/2;
end


% build the reverse centering homography % TODO : THIS MATRIX SHOULD
% INCLUDE THE SIZE OF THE REFERENCE IMAGE AND NOT w and h
HoutInv = eye(3);
HoutInv(1,3) = width{referenceImage}/2;
HoutInv(2,3) = height{referenceImage}/2;


% build the raotation matrices
R = cell(1,nbCamera);
for i=1:nbCamera
    if i == referenceImage
        R{i} = eulerAngles([0,Ry(i),Rz(i)]);
    else
        R{i} = eulerAngles([Rx(i),Ry(i),Rz(i)]);
    end
end

% build the homography matrices
H = cell(1,nbCamera);
for i=1:nbCamera
    H{i} = HoutInv * Knew{i} * R{i} * inv(Koriginal{i}) * Hcenter{i};
end



