function [imagesCell correspondencesCell width height] = loadInputData(dirName, patternName)
% load the images in dirName and store them as a cell array of images.
%
% [IMAGESCELL CORRESPONDENCESCELL WIDTH HEIGHT] = LOADINPUTDATA(DIRNAME, PATTERNNAME)
% loads all the images (.jpg) contained in the directory DIRNAME, with format 
% PATTERNNAME (for example: 'image*'). The loaded images are stored in the 
% cell array IMAGESCELL. Each image resolution is store in the cell arrays
% WIDTH and HEIGHT. This fucnction also load the point correspondences
% files that should have teh same name as the corresponding image, with
% extension '.list'.
%
% Copyright (C) by University Paris-Est - Vincent NOZICK   
% Mail : nozick@univ-mlv.fr
%   
% This source code is free software; you can redistribute it and/or modify
% it under the terms of the GNU Lesser General Public License as published by
% the Free Software Foundation; either version 3 of the License, or
% (at your option) any later version.
%
% This source code is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
% GNU Lesser General Public License for more details.
%
% You should have received a copy of the GNU Lesser General Public License
% along with this program. If not, see <http://www.gnu.org/licenses/>.
% 
% Author : Vincent Nozick (nozick@univ-mlv.fr)

% image pattern (.jpeg)
imagePatternName = strcat(patternName,'.jpg');

% correspondence pattern (.list)
correspondencePatternName = strcat(patternName,'.list');

% list of images to be loaded
imageList = dir(fullfile(dirName,imagePatternName));
correspondenceList = dir(fullfile(dirName,correspondencePatternName));

% memory alloc
correspondencesCell = cell(1,numel(correspondenceList));
imagesCell = cell(1,numel(imageList));
width      = cell(1,length(imagesCell));
height     = cell(1,length(imagesCell));

% check data validity
assert(numel(imageList) == numel(correspondenceList), 'invalid data: not the same number of images and of lists.');

% load the images
for k=1:numel(imageList)
    imageFileName = fullfile(dirName,imageList(k).name);
    fprintf(1,'   %s...\n',imageFileName);
    
    imagesCell{k} = imread(imageFileName);
    width{k}      = size(imagesCell{k},2);
    height{k}     = size(imagesCell{k},1);
end

% load the correspondences
for k=1:numel(correspondenceList)
    dataFileName = fullfile(dirName,correspondenceList(k).name);
    fprintf(1,'   %s...\n',dataFileName);
    correspondencesCell{k} = load(dataFileName);
end
