%function multipleRectification()
% compute an image rectification without calibration (only correspondences)

% This function reads some images and point matches from files.
% It outputs the rectified images and the corresponding camera matrices.

% Vincent Nozick (vnozick@univ-mlv.fr) 2011

% reference image 
referenceImage = 1;

% load the images and the point correspondences
fprintf(1,'\nLoad images and point correspondences ...\n');
[images correspondences width height]= loadInputData('inputData/','image*');
nbImages = length(images);

% draw and save image point correspondences
saveImages('outputData/','correspondences',drawCorrepsondences(images,correspondences));

% vector a : parameters to find (4 per camera), starting value is 0
a0 = zeros(1,4*nbImages);

% non linear minimization
fprintf(1,'\nRunning Levenberg-Marquardt ...\n');
options = optimset('MaxIter',3000,'MaxFunEvals',10000);
lowerBounds = -pi/2 * ones(1,4*nbImages);
upperBounds =  pi/2 * ones(1,4*nbImages);
for i=1:nbImages
    lowerBounds(nbImages*i) = -1.5;
    upperBounds(nbImages*i) =  1.5;
end
a = lsqnonlin(@(x) costMultiRectification(x,width,height,correspondences), a0, lowerBounds, upperBounds, options);

% get back the final parameters
fprintf(1,'\nCamera calibration ...\n');
H = getHomographies(a,width,height,referenceImage);

% (optional) scale the images homographies
fprintf(1,'\nRectify the images ...\n');
scaleFactor = 0.5; % near 1 may crop the images, near 0.5 may involve big black borders
Hscale = [scaleFactor, 0, (1-scaleFactor)*width{1}/2; 0, scaleFactor, (1-scaleFactor)*height{1}/2; 0, 0, 1];
for i=1:nbImages
    H{i} = Hscale * H{i}; 
end

% rectify the images
finalImages = cell(1,nbImages);
boundingBox = [1,1,width{referenceImage},height{referenceImage}];
for i=1:nbImages

    for c = 1:3
        [finalImages{i}(:,:,c)] = imageWarp(images{i}(:,:,c), H{i}, 'bilinear',boundingBox);
    end
end

% save the rectified images
saveImages('outputData/','rectified',finalImages);

% display the images
I1 = images{1};
I2 = finalImages{1};
for i=2:nbImages
    I1 = horzcat(I1,images{i});
    I2 = horzcat(I2,finalImages{i});
end
hold on;
subplot(211);
imshow(I1);
subplot(212);
imshow(I2);
hold off;

